@@ -1,5 +1,6 @@
 """ Apps file for setting core package when app is ready
 """
+
 import sys
 
 from django.apps import AppConfig
@@ -9,6 +10,7 @@ class UserRegistrationAppConfig(AppConfig):
     """Core application settings."""
 
     name = "core_user_registration_app"
+    verbose_name = "Core User Registration App"
 
     def ready(self):
         """Run when the app is ready.
@@ -19,4 +21,4 @@ class UserRegistrationAppConfig(AppConfig):
         if "migrate" not in sys.argv:
             import core_user_registration_app.discover as discover
 
-            discover.init_registration_app()
+            discover.init_permissions()
