@@ -80,10 +80,10 @@ def insert_metadata(user, account_id, metadata):
 
 
     """
-
-    account_request_metadata = get_account_request_metadata_by_id(account_id)
-    account_request_metadata.metadata = metadata
-    account_request_metadata.save()
+    # NOTE: used queryset.update to change metadata as assignment would not save change in database
+    AccountRequestMetadata.objects.filter(pk=account_id).update(
+        metadata=metadata
+    )
 
 
 def create_account_request(user):
@@ -112,7 +112,9 @@ def create_account_request(user):
         )
 
         context = {"URI": SERVER_URI}
-        template_path = "core_website_app/admin/email/request_account_for_admin.html"
+        template_path = (
+            "core_website_app/admin/email/request_account_for_admin.html"
+        )
         send_mail_api.send_mail_to_administrators(
             subject="New Account Request",
             path_to_template=template_path,
